"""
    EMIL AccountService

    The EMIL AccountService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.account
from eis.account.model.create_account_request_dto import CreateAccountRequestDto


class TestCreateAccountRequestDto(unittest.TestCase):
    """CreateAccountRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateAccountRequestDto(self):
        """Test CreateAccountRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateAccountRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    EMIL AccountService

    The EMIL AccountService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.account
from eis.account.model.inline_response503 import InlineResponse503


class TestInlineResponse503(unittest.TestCase):
    """InlineResponse503 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse503(self):
        """Test InlineResponse503"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InlineResponse503()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
